Moscore
===============================================

.. currentmodule:: skchange.change_detectors

.. autoclass:: Moscore

.. include:: skchange.change_detectors.Moscore.examples

.. raw:: html

    <div class="clearer"></div>